valueFieldType property
Value type of the map. Per proto2 and proto3 specs, this can be any type
other than map, and the type cannot be repeated.
The int value is interpreted the same way as FieldInfo.type.
Implementation
final int valueFieldType;